@@ -3,7 +3,7 @@ import traceback
 import logging
 import time
 
-def ask(configs : list, questions : list, output_file_path : str, verbose: bool = False, model : str = "gpt-3.5-turbo"):
+def ask(configs : list, questions : list, output_file_path : str, verbose: bool = False, model : str = "gpt-3.5-turbo", system_text : str = None):
     '''
     `config` should be a list containing your ChatGPT access tokens / email and password\n
     `questions` should contain a list of questions you would like ChatGPT to answer.\n
@@ -13,7 +13,7 @@ def ask(configs : list, questions : list, output_file_path : str, verbose: bool
     while redo:
         if not isinstance(questions, list): raise ValueError("[questions] should be a list")
 
-        try: ask_questions(configs=configs, questions=questions, output_file_path=output_file_path, verbose=verbose, model=model)
+        try: ask_questions(configs=configs, questions=questions, output_file_path=output_file_path, verbose=verbose, model=model, system_text=system_text)
         except Exception as e: 
             logging.error(traceback.format_exc())
         
